@@ -1,5 +1,5 @@
+use crate::tokio::{self, sync::mpsc::error::SendError};
 use core::fmt::Debug;
-use tokio::{self, sync::mpsc::error::SendError};
 
 /// Error declarations.
 #[derive(Clone, Copy, Debug)]
